uid the asset unique identifier
name the name of the asset
asset_type the type of asset (block, survey, question, or template)
owner_userame the user account of the owner of the asset
date_create when the asset was created
date_modified when the asset was last modified
deployed whether or not the asset is currently deployed
submissions the number of submissions for the asset (survey)